Вирутальный сервер - используется для запуска нескольких локальных устройств в одном процессе операционной системы.

Список запущенных локальных устройств находится /oic/con:b3rundev

Список доступных для запуска устройств (классов) находится /oic/mnt:b3avdev.
